pywr.recorders.SeasonalFlowDurationCurveRecorder
================================================

.. currentmodule:: pywr.recorders

.. autoclass:: SeasonalFlowDurationCurveRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SeasonalFlowDurationCurveRecorder.after
      ~SeasonalFlowDurationCurveRecorder.aggregated_value
      ~SeasonalFlowDurationCurveRecorder.before
      ~SeasonalFlowDurationCurveRecorder.finish
      ~SeasonalFlowDurationCurveRecorder.is_season
      ~SeasonalFlowDurationCurveRecorder.load
      ~SeasonalFlowDurationCurveRecorder.register
      ~SeasonalFlowDurationCurveRecorder.reset
      ~SeasonalFlowDurationCurveRecorder.setup
      ~SeasonalFlowDurationCurveRecorder.to_dataframe
      ~SeasonalFlowDurationCurveRecorder.unregister
      ~SeasonalFlowDurationCurveRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SeasonalFlowDurationCurveRecorder.agg_func
      ~SeasonalFlowDurationCurveRecorder.children
      ~SeasonalFlowDurationCurveRecorder.comment
      ~SeasonalFlowDurationCurveRecorder.data
      ~SeasonalFlowDurationCurveRecorder.epsilon
      ~SeasonalFlowDurationCurveRecorder.fdc
      ~SeasonalFlowDurationCurveRecorder.ignore_nan
      ~SeasonalFlowDurationCurveRecorder.is_constraint
      ~SeasonalFlowDurationCurveRecorder.is_objective
      ~SeasonalFlowDurationCurveRecorder.model
      ~SeasonalFlowDurationCurveRecorder.name
      ~SeasonalFlowDurationCurveRecorder.node
      ~SeasonalFlowDurationCurveRecorder.parents
      ~SeasonalFlowDurationCurveRecorder.temporal_agg_func
   
   